Library for Nearest Neighbor Search in High-Dimensional Spaces
==============================================================

This is a library for nearest neighbor search in high dimensional spaces.
